import { Construct, IConstruct } from "constructs";
import { IParent } from "./parent";
import { IPolicyAttachmentTarget } from "./policy-attachment";
/**
 * Specifies the feature set supported by the new organization.
 *
 * Each feature set supports different levels of functionality.
 *
 * @see https://docs.aws.amazon.com/organizations/latest/userguide/orgs_getting-started_concepts.html#feature-set
 * @stability stable
 */
export declare enum FeatureSet {
    /**
     * All member accounts have their bills consolidated to and paid by the management account.
     *
     * For more information, see [Consolidated billing](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_getting-started_concepts.html#feature-set-cb-only) in the AWS Organizations User Guide. The consolidated billing feature subset isn’t available for organizations in the AWS GovCloud (US) Region.
     *
     * @stability stable
     */
    CONSOLIDATED_BILLING = "CONSOLIDATED_BILLING",
    /**
     * In addition to all the features supported by the consolidated billing feature set, the management account can also apply any policy type to any member account in the organization.
     *
     * For more information, see [All features](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_getting-started_concepts.html#feature-set-all) in the AWS Organizations User Guide.
     *
     * @stability stable
     */
    ALL = "ALL"
}
/**
 * @stability stable
 */
export interface OrganizationProps {
    /**
     * Enabling features in your organization.
     *
     * @default ALL
     * @see https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_org_support-all-features.html
     * @stability stable
     */
    readonly featureSet?: FeatureSet;
}
/**
 * Creates an organization to consolidate your AWS accounts so that you can administer them as a single unit.
 *
 * An organization has one management account along with zero or more member accounts. You can organize the accounts in a hierarchical, tree-like structure with a root at the top and organizational units nested under the root. Each account can be directly in the root, or placed in one of the OUs in the hierarchy. An organization has the functionality that is determined by the feature set that you enable.
 *
 * <strong>The account whose user is calling the CreateOrganization operation automatically becomes the management account of the new organization.</strong>
 *
 * <strong>For deletion of an organization you must previously remove all the member accounts, OUs, and policies from the organization!</strong>
 *
 * @see https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_org_create.html#create-org
 * @stability stable
 */
export interface IOrganization extends IConstruct {
    /**
     * The unique identifier (ID) of an organization.
     *
     * The regex pattern for an organization ID string requires "o-" followed by from 10 to 32 lowercase letters or digits.
     *
     * @stability stable
     */
    readonly organizationId: string;
    /**
     * The Amazon Resource Name (ARN) of an organization.
     *
     * @stability stable
     */
    readonly organizationArn: string;
    /**
     * Specifies the functionality that currently is available to the organization.
     *
     * If set to "ALL", then all features are enabled and policies can be applied to accounts in the organization. If set to "CONSOLIDATED_BILLING", then only consolidated billing functionality is available.
     *
     * @stability stable
     */
    readonly featureSet: FeatureSet;
    /**
     * The Amazon Resource Name (ARN) of the account that is designated as the management account for the organization.
     *
     * @stability stable
     */
    readonly managementAccountArn: string;
    /**
     * The unique identifier (ID) of the management account of an organization.
     *
     * @stability stable
     */
    readonly managementAccountId: string;
    /**
     * The email address that is associated with the AWS account that is designated as the management account for the organization.
     *
     * @stability stable
     */
    readonly managementAccountEmail: string;
    /**
     * The root of the current organization, which is automatically created.
     *
     * @stability stable
     */
    readonly root: Root;
}
/**
 * @stability stable
 */
export declare class Organization extends Construct implements IOrganization {
    /**
     * The unique identifier (ID) of an organization.
     *
     * The regex pattern for an organization ID string requires "o-" followed by from 10 to 32 lowercase letters or digits.
     *
     * @stability stable
     */
    readonly organizationId: string;
    /**
     * The Amazon Resource Name (ARN) of an organization.
     *
     * @stability stable
     */
    readonly organizationArn: string;
    /**
     * Specifies the functionality that currently is available to the organization.
     *
     * If set to "ALL", then all features are enabled and policies can be applied to accounts in the organization. If set to "CONSOLIDATED_BILLING", then only consolidated billing functionality is available.
     *
     * @stability stable
     */
    readonly featureSet: FeatureSet;
    /**
     * The Amazon Resource Name (ARN) of the account that is designated as the management account for the organization.
     *
     * @stability stable
     */
    readonly managementAccountArn: string;
    /**
     * The unique identifier (ID) of the management account of an organization.
     *
     * @stability stable
     */
    readonly managementAccountId: string;
    /**
     * The email address that is associated with the AWS account that is designated as the management account for the organization.
     *
     * @stability stable
     */
    readonly managementAccountEmail: string;
    /**
     * The root of the current organization, which is automatically created.
     *
     * @stability stable
     */
    readonly root: Root;
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props: OrganizationProps);
}
/**
 * @stability stable
 */
export interface RootProps {
    /**
     * @stability stable
     */
    readonly organization: IOrganization;
}
/**
 * The parent container for all the accounts for your organization.
 *
 * If you apply a policy to the root, it applies to all organizational units (OUs) and accounts in the organization.
 * <strong>Currently, you can have only one root. AWS Organizations automatically creates it for you when you create an organization.</strong>
 *
 * @see https://docs.aws.amazon.com/organizations/latest/userguide/orgs_getting-started_concepts.html
 * @stability stable
 */
export declare class Root extends Construct implements IParent, IPolicyAttachmentTarget {
    /**
     * The unique identifier (ID) for the root.
     *
     * The regex pattern for a root ID string requires "r-" followed by from 4 to 32 lowercase letters or digits.
     *
     * @stability stable
     */
    readonly rootId: string;
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props: RootProps);
    /**
     * The unique identifier (ID) of the parent root or OU that you want to create the new OU in.
     *
     * @stability stable
     */
    identifier(): string;
}
