import { Construct, IConstruct } from "constructs";
import { IParent } from "./parent";
import { IPolicyAttachmentTarget } from "./policy-attachment";
/**
 * @stability stable
 */
export interface OrganizationalUnitProps {
    /**
     * The friendly name to assign to the new OU.
     *
     * @stability stable
     */
    readonly organizationalUnitName: string;
    /**
     * The parent root or OU that you want to create the new OrganizationalUnit in.
     *
     * @stability stable
     */
    readonly parent: IParent;
}
/**
 * A container for accounts within a root.
 *
 * An OU also can contain other OUs, enabling you to create a hierarchy that resembles an upside-down tree, with a root at the top and branches of OUs that reach down, ending in accounts that are the leaves of the tree. When you attach a policy to one of the nodes in the hierarchy, it flows down and affects all the branches (OUs) and leaves (accounts) beneath it. An OU can have exactly one parent, and currently each account can be a member of exactly one OU.
 *
 * <strong>You must first move all accounts out of the OU and any child OUs, and then you can delete the child OUs.</strong>
 *
 * @stability stable
 */
export interface IOrganizationalUnit extends IPolicyAttachmentTarget, IParent, IConstruct {
    /**
     * The unique identifier (ID) associated with this OU.
     *
     * The regex pattern for an organizational unit ID string requires "ou-" followed by from 4 to 32 lowercase letters or digits (the ID of the root that contains the OU). This string is followed by a second "-" dash and from 8 to 32 additional lowercase letters or digits.
     *
     * @stability stable
     */
    readonly organizationalUnitId: string;
    /**
     * The Amazon Resource Name (ARN) of this OU.
     *
     * For more information about ARNs in Organizations, see [ARN Formats Supported by Organizations](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsorganizations.html#awsorganizations-resources-for-iam-policies) in the AWS Service Authorization Reference.
     *
     * @stability stable
     */
    readonly organizationalUnitArn: string;
    /**
     * The friendly name of this OU.
     *
     * @stability stable
     */
    readonly organizationalUnitName: string;
}
/**
 * @stability stable
 */
export declare abstract class OrganizationalUnitBase extends Construct implements IOrganizationalUnit {
    /**
     * The unique identifier (ID) associated with this OU.
     *
     * The regex pattern for an organizational unit ID string requires "ou-" followed by from 4 to 32 lowercase letters or digits (the ID of the root that contains the OU). This string is followed by a second "-" dash and from 8 to 32 additional lowercase letters or digits.
     *
     * @stability stable
     */
    abstract readonly organizationalUnitId: string;
    /**
     * The Amazon Resource Name (ARN) of this OU.
     *
     * For more information about ARNs in Organizations, see [ARN Formats Supported by Organizations](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsorganizations.html#awsorganizations-resources-for-iam-policies) in the AWS Service Authorization Reference.
     *
     * @stability stable
     */
    abstract readonly organizationalUnitArn: string;
    /**
     * The friendly name of this OU.
     *
     * @stability stable
     */
    abstract readonly organizationalUnitName: string;
    /**
     * @stability stable
     */
    identifier(): string;
}
/**
 * @stability stable
 */
export interface OrganizationalUnitAttributes {
    /**
     * @stability stable
     */
    readonly organizationalUnitId: string;
    /**
     * @stability stable
     */
    readonly parent: IParent;
}
/**
 * @stability stable
 */
export declare class OrganizationalUnit extends OrganizationalUnitBase {
    /**
     * @stability stable
     */
    static fromOrganizationalUnitId(scope: Construct, id: string, attrs: OrganizationalUnitAttributes): IOrganizationalUnit;
    /**
     * The unique identifier (ID) associated with this OU.
     *
     * The regex pattern for an organizational unit ID string requires "ou-" followed by from 4 to 32 lowercase letters or digits (the ID of the root that contains the OU). This string is followed by a second "-" dash and from 8 to 32 additional lowercase letters or digits.
     *
     * @stability stable
     */
    readonly organizationalUnitId: string;
    /**
     * The Amazon Resource Name (ARN) of this OU.
     *
     * For more information about ARNs in Organizations, see [ARN Formats Supported by Organizations](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsorganizations.html#awsorganizations-resources-for-iam-policies) in the AWS Service Authorization Reference.
     *
     * @stability stable
     */
    readonly organizationalUnitArn: string;
    /**
     * The friendly name of this OU.
     *
     * @stability stable
     */
    readonly organizationalUnitName: string;
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props: OrganizationalUnitProps);
    /**
     * @stability stable
     */
    identifier(): string;
}
